import { select, 
        json,
        csv,
        tsv, 
        geoPath,
        geoMercator,
        scaleOrdinal,
        schemeCategory10,
        zoom,
        event } from 'd3';
import { feature } from 'topojson';

const svg = select('svg');
const width = parseFloat(svg.attr('width'));
const height = +svg.attr('height');
let stateNames = [];

const projection = geoMercator()
			.clipExtent([[0,0],[width,height]])
			.center([140, 30])
			.scale(700);

const pathGenerator = geoPath()
		.projection(projection);

const g = svg.append('g');

svg.call(zoom().on('zoom', () => {
	g.attr('transform', event.transform)
}));

Promise.all([json('https://gist.githubusercontent.com/avinashchinta99/6fcf893d9cfd0bb90e03583cfe55c7d6/raw/07df0d96e925d6c11c1bf21b00840eeedef94f53/mapdata.json')
            ]).then(([stateJSON, districtJSON]) => {
	 
  const stateGroup = g.append('g');
  			
  const states = feature(stateJSON, stateJSON.objects.JPN_adm1);
  
  const colorScale = scaleOrdinal(schemeCategory10);
  
  const statePath = stateGroup.selectAll('path')
    .data(states.features)
  statePath.enter().append('path')
    .attr('class', 'states')
    .attr('d', d => pathGenerator(d))
});
      